/**
 * @Description     SMTable 基于antd Table封装的表格组件，内置批量多选，自定义表头DOM，通用数美loading框
 * @Author          haojie(chenhaojie@ishumei.com)、junjie (yangjunjie@ishumei.com)
 * @Date            2021-08-10
 * @Path            sm-antd/src/components/SMTable
 * @Log             ts+hooks 重构
 * /

/**
 * SMTable 基于antd Table封装的表格组件，内置批量多选，自定义表头DOM，通用数美loading框
 *
 * @param {Array}    dataSource          数据源
 * @param {Array}    columns             表头配置
 * @param {Boolean}  loading             加载状态
 * @param {Number}   totalCount          总数
 * @param {Number}   current             当前页码
 * @param {Number}   pageSize            每页条数
 * @param {Array}    pageSizeOptions     每页条数配置
 * @param {Boolean}  isHidePagination    是否隐藏底部Pagination
 * @param {String}   idName              唯一标识字段名
 * @param {Object}   scroll              表格滚动设置
 * @param {Object}   rowSelection        多选属性
 * @param {Function} selectionExtraDom   多选自定义DOM
 * @param {Object}   extraDom            自定义表头DOM
 * @param {Function} onSearch            页码每页条数变化时的回调
 * @param {Object}   wrapperStyle        容器样式
 * @param {string}   setTableKey         table的唯一key，设置则显示列设置按钮
 * @param {Boolean}  setLocalTable       列配置信息是否localStorage存储
 * @param {Function} showTotal           自定义showTotal展示
 * @param {Function} selectShowDom       自定义selectShowDom展示
 * @param {Object}   antdProps           antd自带属性
 * @param {Boolean}  isDrag              是否拖拽，如果需要拖拽表头的功能，则需求设置宽度
 * @param {Function} getNewTableColumn   把最新表格宽度传出去
 */
import React from 'react';
import type { TableColumnType } from 'antd';
import { TableState, ColumnsState, Pagination, RowSelection, i18nProps } from '@/schemas/table';
export interface SMTableColumnType<T> extends TableColumnType<T> {
    defaultHide?: boolean;
}
export interface SMTableProps extends SMTableStateModel {
    totalCount?: number;
    current?: number;
    pageSize?: number;
    pageSizeOptions?: string[];
    idName?: string;
    scroll?: any;
    selectionExtraDom?: () => React.ReactNode;
    selectShowDom?: () => React.ReactNode;
    getNewTableColumn?: (column: Object) => void;
    extraDom?: React.ReactNode;
    onSearch?: (current: number, pageSize: number) => void;
    wrapperStyle?: any;
    antdProps?: any;
    loading?: boolean;
    isHidePagination?: boolean;
    columns?: SMTableColumnType<any>[];
    setTableKey?: string;
    setLocalTable?: boolean;
    rowSelection?: RowSelection;
    showTotal?: (total: number) => string;
    pagination?: Pagination;
    popoverStyle?: object;
    i18nText?: i18nProps;
    isDrag?: boolean;
    customLoadingUrl?: string;
}
export interface SMTableStateModel extends TableState {
    dataSource?: any[];
    columnsMap?: ColumnsState;
    newTableColumn?: any[];
}
declare const SMTable: React.FC<SMTableProps>;
export default SMTable;
